@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2002 George Lebl
+ * Copyright (C) 1997-2003 George Lebl
  *
  * Author: George Lebl
  *
@@ -455,7 +455,7 @@ whack_help (const char *func)
 }
 
 void
-gel_push_file_info(char *file,int line)
+gel_push_file_info(const char *file,int line)
 {
 	curfile = g_slist_prepend(curfile,file?g_strdup(file):NULL);
 	curline = g_slist_prepend(curline,GINT_TO_POINTER(line));
@@ -2168,6 +2168,13 @@ static void
 help_on (const char *text)
 {
 	GelHelp *help;
+	GelHelp not_documented = { NULL /* func */,
+			           NULL /* aliasfor */,
+				   NULL /* category */,
+				   _("Not documented"),
+				   NULL /* aliases */,
+				   NULL /* help_link */,
+				   NULL /* help_html */ };
 	GelEFunc *f;
 	int i;
 
@@ -2186,9 +2193,8 @@ help_on (const char *text)
 		char *s = g_strdup_printf (_("'%s' is not documented"), text);
 		(*errorout) (s);
 		g_free (s);
-		do_black ();
-		gel_output_pop_nonotify (main_out);
-		return;
+		not_documented.func = (char *)text;
+		help = &not_documented;
 	}
 
 	if (help->aliasfor) {
@@ -2266,7 +2272,7 @@ set_new_calcstate(calcstate_t state)
 static void
 load_fp(FILE *fp, char *dirprefix)
 {
-	my_yy_open(fp);
+	gel_lexer_open(fp);
 	while(1) {
 		gel_evalexp(NULL, fp, NULL, NULL, FALSE, dirprefix);
 		if(got_eof) {
@@ -2276,7 +2282,7 @@ load_fp(FILE *fp, char *dirprefix)
 		if(interrupted)
 			break;
 	}
-	my_yy_close(fp);
+	gel_lexer_close(fp);
 	/*fclose(fp);*/
 }
 
@@ -2608,7 +2614,7 @@ gel_parseexp(const char *str, FILE *infile, gboolean exec_commands, gboolean tes
 		if(str[l-1] != '\n')
 			write(lex_fd[1], "\n", 1);
 		close(lex_fd[1]);
-		my_yy_open(infile);
+		gel_lexer_open(infile);
 	}
 
 	gel_command = GEL_NO_COMMAND;
@@ -2618,7 +2624,7 @@ gel_parseexp(const char *str, FILE *infile, gboolean exec_commands, gboolean tes
 	/*yydebug=TRUE;*/  /*turn debugging of parsing on here!*/
 	if(testparse) ignore_end_parse_errors = TRUE;
 	got_end_too_soon = FALSE;
-	my_yy_parse(infile);
+	gel_lexer_parse(infile);
 	ignore_end_parse_errors = FALSE;
 
 	/*while(yyparse() && !feof(yyin))
@@ -2629,7 +2635,7 @@ gel_parseexp(const char *str, FILE *infile, gboolean exec_commands, gboolean tes
 			;
 		close(lex_fd[0]);
 		fflush(infile);
-		my_yy_close(infile);
+		gel_lexer_close(infile);
 		/*fclose(infile);*/
 	}
 	
